@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub new {
 	my ($class) = @_;
@@ -1124,8 +1124,7 @@ sub parse {
     my ($class, $program) = @_;
     if($program =~ $parser) {
         my $code = $/{Lang}->X();
-
-        eval $code;
+        return $code;
     } else {
         print "Not matched";
     }
@@ -1141,10 +1140,11 @@ Lang::HL
 =head1 SYNOPSIS
 
   $> hlc <directoryName>
+  $> hlg <directoryName>
 
 =head1 DESCRIPTION
 
-HL is a programming language, for more documentation please visit http://.....
+HL is a programming language, for more documentation please visit https://hl-lang.github.io
 
 =head1 AUTHOR
 
@@ -1152,9 +1152,19 @@ Rajkumar Reddy
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2022 by Rajkumar Reddy
+Copyright (C) 2022 by Rajkumar Reddy
 
-Opensourced
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 =cut
